import java.awt.BorderLayout;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.text.DefaultCaret;


/**
 * A Java application to serve as a reminder of how some of the basic GUI
 * elements are pieced together in Java.  This isn't meant to be pretty (I'll leave
 * it to you to make your project GUI pretty.); it's simply meant to demonstrate
 * several GUI elements. 
 * 
 * @author Tom Kelliher
 *
 */
public class Controller {
	
	public Controller() {
		// Construct the application's window.
		JFrame window = new JFrame();
		window.setSize(800, 800);
		window.setLayout(new BorderLayout());
		window.setTitle("Window Title");
		
		//This panel will hold the label used to display an image and the button
		// which is used to change the displayed image.  This is the standard way
		// of displaying an image in a Java application.  Java does not make it easy
		// to resize an image.  Image sizing should be done by pre-processing images
		// in, for example, gimp in Linux.
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		ImageIcon[] images = new ImageIcon[2];
		images[0] = new ImageIcon("Images/daemon.gif");
		images[1] = new ImageIcon("Images/linuxPenguin.jpeg");
		JLabel label = new JLabel(images[0]);
		panel.add(label, BorderLayout.CENTER);
		JButton button = new JButton("Change Image");
		button.addActionListener(new ButtonListener(label, images));
		panel.add(button, BorderLayout.SOUTH);
		window.add(panel, BorderLayout.NORTH);
		
		// This panel will hold the output display JTextArea object.
		JTextArea textArea = new JTextArea(10, 20);
		JScrollPane display = new JScrollPane(textArea);
		label = new JLabel("Display");
		panel = new JPanel();
		panel.setLayout(new BorderLayout());
		panel.add(display, BorderLayout.CENTER);
		panel.add(label, BorderLayout.WEST);
		window.add(panel, BorderLayout.CENTER);
		
		// This Panel will hold one of the input JTextField objects.
		panel = new JPanel();
		panel.setLayout(new BorderLayout());
		label = new JLabel("Input 1");
		panel.add(label, BorderLayout.WEST);
		JTextField input = new JTextField(15);
		input.addActionListener(new InputListener(textArea));
		panel.add(input, BorderLayout.CENTER);
		window.add(panel, BorderLayout.SOUTH);
		
		// This panel will hold the other input JTextField object.
		panel = new JPanel();
		panel.setLayout(new BorderLayout());
		label = new JLabel("Input 2");
		panel.add(label, BorderLayout.WEST);
		input = new JTextField(10);
		input.addActionListener(new InputListener(textArea));
		panel.add(input, BorderLayout.CENTER);
		window.add(panel, BorderLayout.WEST);
		
		// Finish preparing the window and display it.
		window.pack();
		window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		window.setVisible(true);
	}

	public static void main(String[] args) {
		new Controller();
	}

}
